clear
set more off
set matsize 1000

log using "replication_pm_cook_t1-t8.log", replace

***************************************************************************************
*** Table 1. Evidence for Nutritional Complementarity: Correlation across Nutrients ***
***************************************************************************************

*Use appropriate path file
use "pm_nutrition_web.dta", clear

pwcorr pot milk ow nw beef, star(.1)


******************
*** Tables 2-8 ***
******************

*Use appropriate path file
use "pm_base_web.dta", clear

encode isocode, gen(wc)

/*Create variables for sample of countries in NQ*/
gen lpf = lpf_pi
	replace lpf = ext_lpf if lpf_pi==.
	*Replace lactase persistence frequency with aboriginal population prior to European colonization for Neo-Europes
	*Colonization dates for Neo-Europes from Ertan, Fiszbein, and Putterman 2012
	replace lpf = .36 if isocode=="NZL" & year<1769
	replace lpf = .16 if isocode=="AUS" & year<1820
	
replace yst = ext_yst if yst==.
replace pdiv = ext_pdiv if pdiv==.
replace fstdist1500_uk = ext_fst if fstdist1500_uk==.

/*LPFxPost*/
gen lpf_post = lpf*post
gen ln_wpot_lpf_post = ln_wpot_post*lpf_post

/*Interaction of key variables with year indicator*/
foreach x in 1000 1100 1200 1300 1400 1500 1600 1700 1750 1800 1850 1900{
	gen ln_wpot_`x'=ln_wpot*ydum`x'
	gen lpf_`x'=lpf*ydum`x'
	gen ln_pot_milk_`x'=ln_wpot*lpf*ydum`x'
	
	gen ln_all_`x'=ln_all*ydum`x'
	gen ln_nworld_`x'=ln_nworld*ydum`x'
	gen ln_oworld_`x'=ln_oworld*ydum`x'
	gen ln_spot_`x'=ln_spot*ydum`x'
	gen ln_silagemaize_`x'=ln_silagemaize*ydum`x'
	gen ln_maize_`x'=ln_maize*ydum`x'
	gen ln_cassava_`x'=ln_cassava*ydum`x'
	
	gen ps_`x' = past_suit*ydum`x'
	gen hus_`x' = husbandry*ydum`x'
	gen anim_`x' = large_animals*ydum`x'
	
	gen ec_`x' = economic_complexity*ydum`x'
	gen yst_`x' = yst*ydum`x'
	gen pol_`x' = political_hierarchies*ydum`x'
	
	gen ln_tropical_`x'=ln_tropical*ydum`x'
	gen ln_rugged_`x'=ln_rugged*ydum`x'
	gen ln_elevation_`x'=ln_elevation*ydum`x'
	
	gen ln_disteq_`x'=ln_disteq*ydum`x'
	gen ln_dist_coast_`x'=ln_dist_coast*ydum`x'
	gen malaria_`x'=malaria*ydum`x'
	gen roman_`x'=roman*ydum`x'
	gen pdiv_`x' = pdiv*ydum`x'	
	gen fst_`x' = fstdist1500_uk*ydum`x'
	
	gen cont_africa_`x'=cont_africa*ydum`x'
	gen cont_asia_`x'=cont_asia*ydum`x'
	gen cont_europe_`x'=cont_europe*ydum`x'
	gen cont_oceania_`x'=cont_oceania*ydum`x'
	}

/* Locals for the control variables */
local ydum_flexible "ydum1100 ydum1200 ydum1300 ydum1400 ydum1500 ydum1600 ydum1700 ydum1750 ydum1800 ydum1850 ydum1900"

local ln_potato_flexible "ln_wpot_1100 ln_wpot_1200 ln_wpot_1300 ln_wpot_1400 ln_wpot_1500 ln_wpot_1600 ln_wpot_1700 ln_wpot_1750 ln_wpot_1800 ln_wpot_1850 ln_wpot_1900"
local milk_flexible "lpf_1100 lpf_1200 lpf_1300 lpf_1400 lpf_1500 lpf_1600 lpf_1700 lpf_1750 lpf_1800 lpf_1850 lpf_1900"
local ln_pot_milk_flexible "ln_pot_milk_1100 ln_pot_milk_1200 ln_pot_milk_1300 ln_pot_milk_1400 ln_pot_milk_1500 ln_pot_milk_1600 ln_pot_milk_1700 ln_pot_milk_1750 ln_pot_milk_1800 ln_pot_milk_1850 ln_pot_milk_1900"

local ln_all_flexible "ln_all_1100 ln_all_1200 ln_all_1300 ln_all_1400 ln_all_1500 ln_all_1600 ln_all_1700 ln_all_1750 ln_all_1800 ln_all_1850 ln_all_1900"
local ln_nworld_flexible "ln_nworld_1100 ln_nworld_1200 ln_nworld_1300 ln_nworld_1400 ln_nworld_1500 ln_nworld_1600 ln_nworld_1700 ln_nworld_1750 ln_nworld_1800 ln_nworld_1850 ln_nworld_1900"
local ln_oworld_flexible "ln_oworld_1100 ln_oworld_1200 ln_oworld_1300 ln_oworld_1400 ln_oworld_1500 ln_oworld_1600 ln_oworld_1700 ln_oworld_1750 ln_oworld_1800 ln_oworld_1850 ln_oworld_1900"
local ln_spot_flexible "ln_spot_1100 ln_spot_1200 ln_spot_1300 ln_spot_1400 ln_spot_1500 ln_spot_1600 ln_spot_1700 ln_spot_1750 ln_spot_1800 ln_spot_1850 ln_spot_1900"
local ln_silagemaize_flexible "ln_silagemaize_1100 ln_silagemaize_1200 ln_silagemaize_1300 ln_silagemaize_1400 ln_silagemaize_1500 ln_silagemaize_1600 ln_silagemaize_1700 ln_silagemaize_1750 ln_silagemaize_1800 ln_silagemaize_1850 ln_silagemaize_1900"
local ln_maize_flexible "ln_maize_1100 ln_maize_1200 ln_maize_1300 ln_maize_1400 ln_maize_1500 ln_maize_1600 ln_maize_1700 ln_maize_1750 ln_maize_1800 ln_maize_1850 ln_maize_1900"
local ln_cassava_flexible "ln_cassava_1100 ln_cassava_1200 ln_cassava_1300 ln_cassava_1400 ln_cassava_1500 ln_cassava_1600 ln_cassava_1700 ln_cassava_1750 ln_cassava_1800 ln_cassava_1850 ln_cassava_1900"

local ps_flexible "ps_1100 ps_1200 ps_1300 ps_1400 ps_1500 ps_1600 ps_1700 ps_1750 ps_1800 ps_1850 ps_1900"
local hus_flexible "hus_1100 hus_1200 hus_1300 hus_1400 hus_1500 hus_1600 hus_1700 hus_1750 hus_1800 hus_1850 hus_1900"
local anim_flexible "anim_1100 anim_1200 anim_1300 anim_1400 anim_1500 anim_1600 anim_1700 anim_1750 anim_1800 anim_1850 anim_1900"

local ec_flexible "ec_1100 ec_1200 ec_1300 ec_1400 ec_1500 ec_1600 ec_1700 ec_1750 ec_1800 ec_1850 ec_1900"
local yst_flexible "yst_1100 yst_1200 yst_1300 yst_1400 yst_1500 yst_1600 yst_1700 yst_1750 yst_1800 yst_1850 yst_1900"
local pol_flexible "pol_1100 pol_1200 pol_1300 pol_1400 pol_1500 pol_1600 pol_1700 pol_1750 pol_1800 pol_1850 pol_1900"

local ln_tropical_flexible "ln_tropical_1100 ln_tropical_1200 ln_tropical_1300 ln_tropical_1400 ln_tropical_1500 ln_tropical_1600 ln_tropical_1700 ln_tropical_1750 ln_tropical_1800 ln_tropical_1850 ln_tropical_1900"
local ln_rugged_flexible "ln_rugged_1100 ln_rugged_1200 ln_rugged_1300 ln_rugged_1400 ln_rugged_1500 ln_rugged_1600 ln_rugged_1700 ln_rugged_1750 ln_rugged_1800 ln_rugged_1850 ln_rugged_1900"
local ln_elevation_flexible "ln_elevation_1100 ln_elevation_1200 ln_elevation_1300 ln_elevation_1400 ln_elevation_1500 ln_elevation_1600 ln_elevation_1700 ln_elevation_1750 ln_elevation_1800 ln_elevation_1850 ln_elevation_1900"

local ln_disteq_flexible "ln_disteq_1100 ln_disteq_1200 ln_disteq_1300 ln_disteq_1400 ln_disteq_1500 ln_disteq_1600 ln_disteq_1700 ln_disteq_1750 ln_disteq_1800 ln_disteq_1850 ln_disteq_1900"
local ln_dist_coast_flexible "ln_dist_coast_1100 ln_dist_coast_1200 ln_dist_coast_1300 ln_dist_coast_1400 ln_dist_coast_1500 ln_dist_coast_1600 ln_dist_coast_1700 ln_dist_coast_1750 ln_dist_coast_1800 ln_dist_coast_1850 ln_dist_coast_1900"
local malaria_flexible "malaria_1100 malaria_1200 malaria_1300 malaria_1400 malaria_1500 malaria_1600 malaria_1700 malaria_1750 malaria_1800 malaria_1850 malaria_1900"
local fst_flexible "fst_1100 fst_1200 fst_1300 fst_1400 fst_1500 fst_1600 fst_1700 fst_1750 fst_1800 fst_1850 fst_1900"
local pdiv_flexible "pdiv_1100 pdiv_1200 pdiv_1300 pdiv_1400 pdiv_1500 pdiv_1600 pdiv_1700 pdiv_1750 pdiv_1800 pdiv_1850 pdiv_1900"

local cont_africa_flexible "cont_africa_1100 cont_africa_1200 cont_africa_1300 cont_africa_1400 cont_africa_1500 cont_africa_1600 cont_africa_1700 cont_africa_1750 cont_africa_1800 cont_africa_1850 cont_africa_1900"
local cont_asia_flexible "cont_asia_1100 cont_asia_1200 cont_asia_1300 cont_asia_1400 cont_asia_1500 cont_asia_1600 cont_asia_1700 cont_asia_1750 cont_asia_1800 cont_asia_1850 cont_asia_1900"
local cont_europe_flexible "cont_europe_1100 cont_europe_1200 cont_europe_1300 cont_europe_1400 cont_europe_1500 cont_europe_1600 cont_europe_1700 cont_europe_1750 cont_europe_1800 cont_europe_1850 cont_europe_1900"
local cont_oceania_flexible "cont_oceania_1100 cont_oceania_1200 cont_oceania_1300 cont_oceania_1400 cont_oceania_1500 cont_oceania_1600 cont_oceania_1700 cont_oceania_1750 cont_oceania_1800 cont_oceania_1850 cont_oceania_1900"


/*Baseline controls*/
local crop_suit "`ln_all_flexible' "
local domesticate_anim "`ps_flexible' `anim_flexible' `hus_flexible'"
local hist_econ_development "`yst_flexible' `ec_flexible' `pol_flexible'"
local env "`ln_elevation_flexible' `ln_tropical_flexible' `ln_rugged_flexible'"

local bc "`crop_suit' `domesticate_anim' `hist_econ_development' `env'"




*************************************
*** Table 2.  Flexible Estimates  ***
*************************************

*The reported R sqr. from estimates below are for within-country variation.
*Correct R Sqr. can be found with areg (not reported in this do-file).

/*Population*/
*Col. (1)
xi: xtreg ln_population `ln_potato_flexible' `milk_flexible' `ln_pot_milk_flexible' i.year, fe i(wc) cluster(isocode)
test (ln_wpot_1750=0) (ln_wpot_1800=0) (ln_wpot_1850=0) (ln_wpot_1900=0) 
test (lpf_1750=0) (lpf_1800=0) (lpf_1850=0) (lpf_1900=0)
test (ln_pot_milk_1750=0) (ln_pot_milk_1800=0) (ln_pot_milk_1850=0) (ln_pot_milk_1900=0)

*Col. (2)
xi: xtreg ln_population `ln_potato_flexible' `milk_flexible' `ln_pot_milk_flexible' `bc' i.year, fe i(wc) cluster(isocode)
test (ln_wpot_1750=0) (ln_wpot_1800=0) (ln_wpot_1850=0) (ln_wpot_1900=0) 
test (lpf_1750=0) (lpf_1800=0) (lpf_1850=0) (lpf_1900=0)
test (ln_pot_milk_1750=0) (ln_pot_milk_1800=0) (ln_pot_milk_1850=0) (ln_pot_milk_1900=0)


/*Urbanization*/
*Col. (3)
xi: xtreg city_pop_share `ln_potato_flexible' `milk_flexible' `ln_pot_milk_flexible' i.year, fe i(wc) cluster(isocode)
estimates store c
test (ln_wpot_1750=0) (ln_wpot_1800=0) (ln_wpot_1850=0) (ln_wpot_1900=0) 
test (lpf_1750=0) (lpf_1800=0) (lpf_1850=0) (lpf_1900=0)
test (ln_pot_milk_1750=0) (ln_pot_milk_1800=0) (ln_pot_milk_1850=0) (ln_pot_milk_1900=0)

*Col. (4)
xi: xtreg city_pop_share `ln_potato_flexible' `milk_flexible' `ln_pot_milk_flexible' `bc' i.year, fe i(wc) cluster(isocode)
estimates store d
test (ln_wpot_1750=0) (ln_wpot_1800=0) (ln_wpot_1850=0) (ln_wpot_1900=0) 
test (lpf_1750=0) (lpf_1800=0) (lpf_1850=0) (lpf_1900=0)
test (ln_pot_milk_1750=0) (ln_pot_milk_1800=0) (ln_pot_milk_1850=0) (ln_pot_milk_1900=0)



**************************************************
*** Table 3A.  Base Complementarity: Population ***
**************************************************

* Col (1)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post i.year, fe i(wc) cluster(isocode)
	*Marginal Effects
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.23  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.39  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.57  

* Col (2)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `crop_suit' i.year, fe i(wc) cluster(isocode)
	*Marginal Effects
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.23  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.39  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.57  


* Col (3)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `domesticate_anim' i.year, fe i(wc) cluster(isocode)
	*Marginal Effects
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.23 
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.39  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.57  

* Col (4)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `hist_econ_development' i.year, fe i(wc) cluster(isocode)
	*Marginal Effects
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.23 
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.39  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.57  

* Col (5)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `env' i.year, fe i(wc) cluster(isocode)
	*Marginal Effects
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.23 
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.39  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.57 

* Col (6)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `bc'  i.year, fe i(wc) cluster(isocode)
	*Marginal Effects
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.23 
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.39  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.57 


*****************************************************
*** Table 3B.  Base Complementarity: Urbanization ***
*****************************************************

* Col (1)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post i.year, fe i(wc) cluster(isocode)
	*Marginal Effects
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.23  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.39  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.57  

* Col (2)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `crop_suit' i.year, fe i(wc) cluster(isocode)
	*Marginal Effects
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.23  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.39  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.57  


* Col (3)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `domesticate_anim' i.year, fe i(wc) cluster(isocode)
	*Marginal Effects
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.23 
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.39  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.57  

* Col (4)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `hist_econ_development' i.year, fe i(wc) cluster(isocode)
	*Marginal Effects
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.23 
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.39  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.57  

* Col (5)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `env' i.year, fe i(wc) cluster(isocode)
	*Marginal Effects
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.23 
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.39  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.57 

* Col (6)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `bc'  i.year, fe i(wc) cluster(isocode)
	*Marginal Effects
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.23 
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.39  
	lincom _b[ln_wpot_post]+ _b[ln_wpot_lpf_post]*.57 
	
	
*************************************************
*** Table 4.  Placebo Test: Additional Crops  ***
*************************************************

gen ln_maize_lpf_post = lpf_post* ln_maize
gen ln_maize_post = ln_maize*post

gen ln_spot_lpf_post = lpf_post* ln_spot
gen ln_spot_post = ln_spot*post

gen ln_cassava_lpf_post = lpf_post* ln_cassava
gen ln_cassava_post = ln_cassava*post

gen ln_silagemaize_lpf_post = lpf_post* ln_silagemaize
gen ln_silagemaize_post = ln_silagemaize*post


/*Maize*/

**Panel A**
*Col (1)
xi: xtreg ln_population ln_maize_post lpf_post ln_maize_lpf_post i.year, fe i(wc) cluster(isocode)

*Col (2)
xi: xtreg ln_population ln_maize_post lpf_post ln_maize_lpf_post `bc' `ln_potato_flexible' i.year, fe i(wc) cluster(isocode)

**Panel B**
*Col (1)
xi: xtreg city_pop_share ln_maize_post lpf_post ln_maize_lpf_post i.year, fe i(wc) cluster(isocode)

*Col (2)
xi: xtreg city_pop_share ln_maize_post lpf_post ln_maize_lpf_post `bc' `ln_potato_flexible' i.year, fe i(wc) cluster(isocode)


/*Sweet Potato*/

**Panel A**
*Col (3)
xi: xtreg ln_population ln_spot_post lpf_post ln_spot_lpf_post i.year, fe i(wc) cluster(isocode)

*Col (4)
xi: xtreg ln_population ln_spot_post lpf_post ln_spot_lpf_post `bc' `ln_potato_flexible' i.year, fe i(wc) cluster(isocode)

**Panel B**
*Col (3)
xi: xtreg city_pop_share ln_spot_post lpf_post ln_spot_lpf_post i.year, fe i(wc) cluster(isocode)

*Col (4)
xi: xtreg city_pop_share ln_spot_post lpf_post ln_spot_lpf_post `bc' `ln_potato_flexible' i.year, fe i(wc) cluster(isocode)


/*Cassava*/

**Panel A**
*Col (5)
xi: xtreg ln_population ln_cassava_post lpf_post ln_cassava_lpf_post i.year, fe i(wc) cluster(isocode)

*Col (6)
xi: xtreg ln_population ln_cassava_post lpf_post ln_cassava_lpf_post `bc' `ln_potato_flexible' i.year, fe i(wc) cluster(isocode)

**Panel B**
*Col (5)
xi: xtreg city_pop_share ln_cassava_post lpf_post ln_cassava_lpf_post i.year, fe i(wc) cluster(isocode)

*Col (6)
xi: xtreg city_pop_share ln_cassava_post lpf_post ln_cassava_lpf_post `bc' `ln_potato_flexible' i.year, fe i(wc) cluster(isocode)


/*Silage Maize*/

**Panel A**
*Col (7)
xi: xtreg ln_population ln_silagemaize_post lpf_post ln_silagemaize_lpf_post i.year, fe i(wc) cluster(isocode)

*Col (8)
xi: xtreg ln_population ln_silagemaize_post lpf_post ln_silagemaize_lpf_post `bc' `ln_potato_flexible' i.year, fe i(wc) cluster(isocode)

**Panel B**
*Col (7)
xi: xtreg city_pop_share ln_silagemaize_post lpf_post ln_silagemaize_lpf_post i.year, fe i(wc) cluster(isocode)

*Col (8)
xi: xtreg city_pop_share ln_silagemaize_post lpf_post ln_silagemaize_lpf_post `bc' `ln_potato_flexible' i.year, fe i(wc) cluster(isocode)



******************************************
*** Table 5.  Placebo Test:  Animals  ***
******************************************
local bc2 "`crop_suit' `anim_flexible' `ps_flexible' `env' `hist_econ_development'"
local bc3 "`crop_suit' `anim_flexible' `hus_flexible' `env' `hist_econ_development'"
local bc4 "`crop_suit' `ps_flexible' `hus_flexible' `env' `hist_econ_development'"


gen hus_pot_post = ln_wpot_post*husbandry
gen hus_post = husbandry*post

gen ps_pot_post = ln_wpot_post*past_suit
gen ps_post = past_suit*post

gen anim_post = large_animals*post
gen anim_pot_post = ln_wpot_post*large_animals



/*Husbandry*/

**Panel A**
*Col (1)
xi: xtreg ln_population hus_post ln_wpot_post hus_pot_post i.year, fe i(wc) cluster(isocode)

*Col (2)
xi: xtreg ln_population hus_post ln_wpot_post hus_pot_post `bc2' `milk_flexible' i.year, fe i(wc) cluster(isocode)

**Panel B**
*Col (1)
xi: xtreg city_pop_share hus_post ln_wpot_post hus_pot_post i.year, fe i(wc) cluster(isocode)

*Col (2)
xi: xtreg city_pop_share hus_post ln_wpot_post hus_pot_post `bc2' `milk_flexible' i.year, fe i(wc) cluster(isocode)


/*Pastoral Suitability*/

**Panel A**
*Col (3)
xi: xtreg ln_population ps_post ln_wpot_post ps_pot_post i.year, fe i(wc) cluster(isocode)

*Col (4)
xi: xtreg ln_population ps_post ln_wpot_post ps_pot_post `bc3' `milk_flexible' i.year, fe i(wc) cluster(isocode)

**Panel B**
*Col (3)
xi: xtreg city_pop_share ps_post ln_wpot_post ps_pot_post i.year, fe i(wc) cluster(isocode)

*Col (4)
xi: xtreg city_pop_share ps_post ln_wpot_post ps_pot_post `bc3' `milk_flexible' i.year, fe i(wc) cluster(isocode)


/*Presence of Large Domesticate Animals*/

**Panel A**
*Col (5)
xi: xtreg ln_population anim_post ln_wpot_post anim_pot_post i.year, fe i(wc) cluster(isocode)

*Col (6)
xi: xtreg ln_population anim_post ln_wpot_post anim_pot_post `bc4' `milk_flexible' i.year, fe i(wc) cluster(isocode)

**Panel B**
*Col (5)
xi: xtreg city_pop_share anim_post ln_wpot_post anim_pot_post i.year, fe i(wc) cluster(isocode)

*Col (6)
xi: xtreg city_pop_share anim_post ln_wpot_post anim_pot_post `bc4' `milk_flexible' i.year, fe i(wc) cluster(isocode)



**********************************************
*** Table 6.  Placebo Test:  Development  ***
**********************************************
local bc5 "`crop_suit' `domesticate_anim' `env' `yst_flexible' `pol_flexible'"
local bc6 "`crop_suit' `domesticate_anim' `env' `ec_flexible'  `pol_flexible'"

gen ec_pot_post = ln_wpot_post*economic_complexity
gen ec_post = economic_complexity*post

replace pd1500=pd1500_nq if pd1500==.
gen pd1500_post = pd1500*post
gen pd1500_pot_post = pd1500*ln_wpot_post

gen ma = yst/1000
gen ma_post = ma*post
gen ma_pot_post = ma*ln_wpot*post


/*Historic Economic Complexity*/

**Panel A**
*Col (1)
xi: xtreg ln_population ec_post ln_wpot_post ec_pot_post i.year, fe i(wc) cluster(isocode)

*Col (2)
xi: xtreg ln_population ec_post ln_wpot_post ec_pot_post `bc5' `milk_flexible' i.year, fe i(wc) cluster(isocode)

**Panel B**
*Col (1)
xi: xtreg city_pop_share ec_post ln_wpot_post ec_pot_post i.year, fe i(wc) cluster(isocode)

*Col (2)
xi: xtreg city_pop_share ec_post ln_wpot_post ec_pot_post `bc5' `milk_flexible' i.year, fe i(wc) cluster(isocode)



/*Population Density in 1500 CE*/

**Panel A**
*Col (3)
xi: xtreg ln_population pd1500_post ln_wpot_post pd1500_pot_post  i.year, fe i(wc) cluster(isocode)

*Col (4)
xi: xtreg ln_population pd1500_post ln_wpot_post pd1500_pot_post `bc' `milk_flexible' i.year, fe i(wc) cluster(isocode)

**Panel B**
*Col (3)
xi: xtreg city_pop_share pd1500_post ln_wpot_post pd1500_pot_post i.year, fe i(wc) cluster(isocode)

*Col (4)
xi: xtreg city_pop_share pd1500_post ln_wpot_post pd1500_pot_post `bc' `milk_flexible' i.year, fe i(wc) cluster(isocode)


/*Millennia of Agriculture*/

**Panel A**
*Col (5)
xi: xtreg ln_population ma_post ln_wpot_post ma_pot_post i.year, fe i(wc) cluster(isocode)

*Col (6)
xi: xtreg ln_population ma_post ln_wpot_post ma_pot_post `bc6' `milk_flexible' i.year, fe i(wc) cluster(isocode)

**Panel B**
*Col (5)
xi: xtreg city_pop_share ma_post ln_wpot_post ma_pot_post i.year, fe i(wc) cluster(isocode)

*Col (6)
xi: xtreg city_pop_share ma_post ln_wpot_post ma_pot_post `bc6' `milk_flexible' i.year, fe i(wc) cluster(isocode)



*****************************************
*** Table 7.  Continent Fixed Effects ***
*****************************************
local cfe "i.year*cont_africa i.year*cont_asia i.year*cont_europe i.year*cont_oceania"

**Panel A**
*Col (1)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `bc'   i.year, fe i(wc) cluster(wc)

*Col (2)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `cfe'  i.year, fe i(wc) cluster(wc)

*Col (3)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post  `bc' `cfe'  i.year, fe i(wc) cluster(wc)
test (_b[ln_wpot_lpf_post] = .0939)


**Panel B**
*Col (1)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `bc'   i.year, fe i(wc) cluster(wc)

*Col (2)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `cfe'  i.year, fe i(wc) cluster(wc)

*Col (3)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post  `bc' `cfe'  i.year, fe i(wc) cluster(wc)
test (_b[ln_wpot_lpf_post] = .0076)



*************************************
*** Table 8.  Additional Controls ***
*************************************

**Panel A**
* Baseline (Col 1)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `bc' i.year, fe i(wc) cluster(isocode)

* Latitude (Col 2)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `ln_disteq_flexible' `bc' i.year, fe i(wc) cluster(isocode)

* Distance from coast (Col 3)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `ln_dist_coast_flexible' `bc' i.year, fe i(wc) cluster(isocode)

* Malaria (Col 4)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `malaria_flexible' `bc' i.year, fe i(wc) cluster(isocode)

* Roman (Col 5)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post i.year*roman `bc' i.year, fe i(wc) cluster(isocode)

* Genetic Diversity (Col 6)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `pdiv_flexible'  `bc'  i.year  , fe i(wc) cluster(isocode)

* Genetic Dist. from Tech Frontier (Col 7)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post  `fst_flexible' `bc' i.year  , fe i(wc) cluster(isocode)

* All controls (Col 8)
xi: xtreg ln_population ln_wpot_post lpf_post ln_wpot_lpf_post `ln_disteq_flexible' `ln_dist_coast_flexible' `malaria_flexible' i.year*roman `pdiv_flexible' `fst_flexible' `bc' i.year, fe i(wc) cluster(isocode)


**Panel B**
* Baseline (Col 1)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `bc' i.year, fe i(wc) cluster(isocode)

* Latitude (Col 2)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `ln_disteq_flexible' `bc' i.year, fe i(wc) cluster(isocode)

* Distance from coast (Col 3)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `ln_dist_coast_flexible' `bc' i.year, fe i(wc) cluster(isocode)

* Malaria (Col 4)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `malaria_flexible' `bc' i.year, fe i(wc) cluster(isocode)

* Roman (Col 5)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post i.year*roman `bc' i.year, fe i(wc) cluster(isocode)

* Genetic Diversity (Col 6)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `pdiv_flexible'  `bc'  i.year  , fe i(wc) cluster(isocode)

* Genetic Dist. from Tech Frontier (Col 7)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post  `fst_flexible' `bc' i.year  , fe i(wc) cluster(isocode)

* All controls (Col 8)
xi: xtreg city_pop_share ln_wpot_post lpf_post ln_wpot_lpf_post `ln_disteq_flexible' `ln_dist_coast_flexible' `malaria_flexible' i.year*roman `pdiv_flexible' `fst_flexible' `bc' i.year, fe i(wc) cluster(isocode)






	

log close
